==> gnumeric-1.9.15.tar.bz2: gnumeric-1.9.15/src/dialogs/help.h <==
/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef GNUMERIC_HELP_H
#define GNUMERIC_HELP_H

/* ../sheet-object-widget.c    */
#define GNUMERIC_HELP_LINK_SO_FRAME	 "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_ADJUSTMENT "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_BUTTON	 "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_RADIO_BUTTON "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_CHECKBOX	 "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_LIST	 "sect-graphics-drawings"

/* dialog-autofilter.c         */
#define GNUMERIC_HELP_LINK_AUTOFILTER_TOP_TEN "sect-data-modify"
#define GNUMERIC_HELP_LINK_AUTOFILTER_CUSTOM "sect-data-modify"

/* dialog-autoformat.c         */
#define GNUMERIC_HELP_LINK_AUTOFORMAT "sect-data-entry"

/* dialog-autosave.c         */
#define GNUMERIC_HELP_LINK_AUTOSAVE "sect-files-autosave"

/* dialog-cell-comment.c       */
#define GNUMERIC_HELP_LINK_CELL_COMMENT "sect-data-comment"

/* dialog-cell-format.c       */
#define GNUMERIC_HELP_LINK_CELL_FORMAT "sect-data-format"

/* dialog-cell-sort.c  */
#define GNUMERIC_HELP_LINK_CELL_SORT "sect-data-modify"

/* dialog-col-row.c    */
#define GNUMERIC_HELP_LINK_GROUP_UNGROUP "sect-worksheets-viewing"

/* dialog-col-width.c  */
#define GNUMERIC_HELP_LINK_COL_WIDTH "sect-worksheets-colrow"

/* dialog-define-names.c       */
#define GNUMERIC_HELP_LINK_DEFINE_NAMES "sect-workbooks-names"
/* dialog-paste-names.c       */
#define GNUMERIC_HELP_LINK_PASTE_NAMES "sect-workbooks-names-paste"

/* dialog-define-table.c       */
#define GNUMERIC_HELP_LINK_DATA_TABLE "sect-data-table"

/* dialog-delete-cells.c       */
#define GNUMERIC_HELP_LINK_DELETE_CELLS "sect-data-delete"

/* dialog-formula-guru.c       */
#define GNUMERIC_HELP_LINK_FORMULA_GURU "sect-data-entry"

/* dialog-function-select.c    */
#define GNUMERIC_HELP_LINK_FUNCTION_SELECT "sect-data-entry"

/* dialog-goal-seek.c  */
#define GNUMERIC_HELP_LINK_GOAL_SEEK "sect-advanced-analysis-goalseek"

/* dialog-goto-cell.c  */
#define GNUMERIC_HELP_LINK_GOTO_CELL "sect-worksheets-viewing"

/* dialog-hyperlink.c  */
#define GNUMERIC_HELP_LINK_HYPERLINK "sect-data-link"

/* dialog-insert-cells.c */
#define GNUMERIC_HELP_LINK_INSERT_CELS "sect-data-insert"

/* dialog-merge.c      */
#define GNUMERIC_HELP_LINK_DATA_MERGE "sect-data-generate"

/* dialog-pivottable.c         */
#define GNUMERIC_HELP_LINK_DATA_SLICER "sect-data-slicer-config"

/* dialog-plugin-manager.c     */
#define GNUMERIC_HELP_LINK_PLUGIN_MANAGER "sect-configuring-plugins"

/* dialog-preferences.c       */
#define GNUMERIC_HELP_LINK_PREFERENCES "sect-configuration-preferences"
#define GNUMERIC_HELP_LINK_AUTOCORRECT "sect-data-entry"

/* dialog-printer-setup.c     */
#define GNUMERIC_HELP_LINK_PRINTER_SETUP_HEADER_CUSTOMIZATION "sect-printing-setup"
#define GNUMERIC_HELP_LINK_PRINTER_SETUP_FOOTER_CUSTOMIZATION "sect-printing-setup"
#define GNUMERIC_HELP_LINK_PRINTER_SETUP_GENERAL "sect-printing-setup"

/* dialog-row-height.c         */
#define GNUMERIC_HELP_LINK_ROW_HEIGHT "sect-worksheets-colrow"

/* dialog-search-replace.c     */
#define GNUMERIC_HELP_LINK_SEARCH_REPLACE "sect-data-modify"

/* dialog-search.c     */
#define GNUMERIC_HELP_LINK_SEARCH "sect-data-modify"

/* dialog-sheet-order.c       */
#define GNUMERIC_HELP_LINK_SHEET_MANAGER "sect-worksheets-managing"

/* dialog-solver.c    */
#define GNUMERIC_HELP_LINK_SOLVER "sect-advanced-analysis-solver"

/* dialog-summary.c   */
#define GNUMERIC_HELP_LINK_SUMMARY "sect-workbooks-docsummary"

/* dialog-tabulate.c  */
#define GNUMERIC_HELP_LINK_TABULATE "sect-data-generate"

/* dialog-view.c      */
#define GNUMERIC_HELP_LINK_VIEW "sect-worksheets-viewing"

/* dialog-workbook-attr.c */
#define GNUMERIC_HELP_LINK_WORKBOOK_ATTRIBUTE "sect-workbooks"

/* dialog-zoom.c      */
#define GNUMERIC_HELP_LINK_ZOOM "sect-worksheets-viewing"

/* dialog-advanced-filter.c  */
#define GNUMERIC_HELP_LINK_ADVANCED_FILTER "sect-data-modify"

/* dialog-analysis-tools.c */
#define GNUMERIC_HELP_LINK_CORRELATION "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_COVARIANCE "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_RANKING "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_FOURIER_ANALYSIS "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_DESCRIPTIVE_STATS "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_MEAN_TESTS "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_F_TEST_TWO_SAMPLE "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_SAMPLING "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_REGRESSION "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_EXP_SMOOTHING "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_MOVING_AVERAGES "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_HISTOGRAM "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_ANOVA_SINGLE_FACTOR "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_ANOVA_TWO_FACTOR "sect-analysis-statistical"

/* dialog-analysis-tool-chi-squared.c */
#define GNUMERIC_HELP_LINK_CHI_SQUARED "sect-analysis-statistical"

/* dialog-analysis-tool-frequency.c */
#define GNUMERIC_HELP_LINK_FREQUENCY "sect-analysis-statistical"

/* dialog-analysis-tool-kaplan-meier.c */
#define GNUMERIC_HELP_LINK_KAPLAN_MEIER "sect-analysis-statistical"

/* dialog-consolidate.c     */
#define GNUMERIC_HELP_LINK_CONSOLIDATE ""

/* dialog-fill-series.c     */
#define GNUMERIC_HELP_LINK_FILL_SERIES "sect-data-entry"

/* dialog-random-generator.c */
#define GNUMERIC_HELP_LINK_RANDOM_GENERATOR "sect-dataentryadv"

/* dialog-random-generator-cor.c */
#define GNUMERIC_HELP_LINK_RANDOM_GENERATOR_COR "sect-dataentryadv"

/* dialog-scenarios.c */
#define GNUMERIC_HELP_LINK_SCENARIOS_ADD "sect-advanced-analysis-scenarios"
#define GNUMERIC_HELP_LINK_SCENARIOS_VIEW "sect-advanced-analysis-scenarios"

/* dialog-shuffle.c   */
#define GNUMERIC_HELP_LINK_DATA_SHUFFLE "sect-data-modify"

/* dialog-simulation.c */
#define GNUMERIC_HELP_LINK_SIMULATION "sect-advanced-analysis-simulation"

/* dialog-define-table.c */
#define GNUMERIC_HELP_LINK_DEFINE_TABLE "sect-data-table"

/* dialog-doc-metadata.c */
#define GNUMERIC_HELP_LINK_METADATA ""

#endif /* GNUMERIC_HELP_H */

==> gnumeric-1.9.17.tar.bz2: gnumeric-1.9.17/src/dialogs/help.h <==
/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef GNUMERIC_HELP_H
#define GNUMERIC_HELP_H

/* ../sheet-object-widget.c    */
#define GNUMERIC_HELP_LINK_SO_FRAME	 "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_ADJUSTMENT "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_BUTTON	 "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_RADIO_BUTTON "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_CHECKBOX	 "sect-graphics-drawings"
#define GNUMERIC_HELP_LINK_SO_LIST	 "sect-graphics-drawings"

/* dialog-autofilter.c         */
#define GNUMERIC_HELP_LINK_AUTOFILTER_TOP_TEN "sect-data-modify"
#define GNUMERIC_HELP_LINK_AUTOFILTER_CUSTOM "sect-data-modify"

/* dialog-autoformat.c         */
#define GNUMERIC_HELP_LINK_AUTOFORMAT "sect-data-entry"

/* dialog-autosave.c         */
#define GNUMERIC_HELP_LINK_AUTOSAVE "sect-files-autosave"

/* dialog-cell-comment.c       */
#define GNUMERIC_HELP_LINK_CELL_COMMENT "sect-data-comment"

/* dialog-cell-format.c       */
#define GNUMERIC_HELP_LINK_CELL_FORMAT "sect-data-format"

/* dialog-cell-sort.c  */
#define GNUMERIC_HELP_LINK_CELL_SORT "sect-data-modify"

/* dialog-col-row.c    */
#define GNUMERIC_HELP_LINK_GROUP_UNGROUP "sect-worksheets-viewing"

/* dialog-col-width.c  */
#define GNUMERIC_HELP_LINK_COL_WIDTH "sect-worksheets-colrow"

/* dialog-define-names.c       */
#define GNUMERIC_HELP_LINK_DEFINE_NAMES "sect-workbooks-names"
/* dialog-paste-names.c       */
#define GNUMERIC_HELP_LINK_PASTE_NAMES "sect-workbooks-names-paste"

/* dialog-define-table.c       */
#define GNUMERIC_HELP_LINK_DATA_TABLE "sect-data-table"

/* dialog-delete-cells.c       */
#define GNUMERIC_HELP_LINK_DELETE_CELLS "sect-data-delete"

/* dialog-formula-guru.c       */
#define GNUMERIC_HELP_LINK_FORMULA_GURU "sect-data-entry"

/* dialog-function-select.c    */
#define GNUMERIC_HELP_LINK_FUNCTION_SELECT "sect-data-entry"

/* dialog-goal-seek.c  */
#define GNUMERIC_HELP_LINK_GOAL_SEEK "sect-advanced-analysis-goalseek"

/* dialog-goto-cell.c  */
#define GNUMERIC_HELP_LINK_GOTO_CELL "sect-worksheets-viewing"

/* dialog-hyperlink.c  */
#define GNUMERIC_HELP_LINK_HYPERLINK "sect-data-link"

/* dialog-insert-cells.c */
#define GNUMERIC_HELP_LINK_INSERT_CELS "sect-data-insert"

/* dialog-merge.c      */
#define GNUMERIC_HELP_LINK_DATA_MERGE "sect-data-generate"

/* dialog-pivottable.c         */
#define GNUMERIC_HELP_LINK_DATA_SLICER "sect-data-slicer-config"

/* dialog-plugin-manager.c     */
#define GNUMERIC_HELP_LINK_PLUGIN_MANAGER "sect-configuring-plugins"

/* dialog-preferences.c       */
#define GNUMERIC_HELP_LINK_PREFERENCES "sect-configuration-preferences"
#define GNUMERIC_HELP_LINK_AUTOCORRECT "sect-data-entry"

/* dialog-printer-setup.c     */
#define GNUMERIC_HELP_LINK_PRINTER_SETUP_HEADER_CUSTOMIZATION "sect-printing-setup"
#define GNUMERIC_HELP_LINK_PRINTER_SETUP_FOOTER_CUSTOMIZATION "sect-printing-setup"
#define GNUMERIC_HELP_LINK_PRINTER_SETUP_GENERAL "sect-printing-setup"

/* dialog-row-height.c         */
#define GNUMERIC_HELP_LINK_ROW_HEIGHT "sect-worksheets-colrow"

/* dialog-search-replace.c     */
#define GNUMERIC_HELP_LINK_SEARCH_REPLACE "sect-data-modify"

/* dialog-search.c     */
#define GNUMERIC_HELP_LINK_SEARCH "sect-data-modify"

/* dialog-sheet-order.c       */
#define GNUMERIC_HELP_LINK_SHEET_MANAGER "sect-worksheets-managing"

/* dialog-solver.c    */
#define GNUMERIC_HELP_LINK_SOLVER "sect-advanced-analysis-solver"

/* dialog-summary.c   */
#define GNUMERIC_HELP_LINK_SUMMARY "sect-workbooks-docsummary"

/* dialog-tabulate.c  */
#define GNUMERIC_HELP_LINK_TABULATE "sect-data-generate"

/* dialog-view.c      */
#define GNUMERIC_HELP_LINK_VIEW "sect-worksheets-viewing"

/* dialog-workbook-attr.c */
#define GNUMERIC_HELP_LINK_WORKBOOK_ATTRIBUTE "sect-workbooks"

/* dialog-zoom.c      */
#define GNUMERIC_HELP_LINK_ZOOM "sect-worksheets-viewing"

/* dialog-advanced-filter.c  */
#define GNUMERIC_HELP_LINK_ADVANCED_FILTER "sect-data-modify"

/* dialog-analysis-tools.c */
#define GNUMERIC_HELP_LINK_CORRELATION "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_COVARIANCE "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_RANKING "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_FOURIER_ANALYSIS "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_DESCRIPTIVE_STATS "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_MEAN_TESTS "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_F_TEST_TWO_SAMPLE "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_SAMPLING "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_REGRESSION "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_EXP_SMOOTHING "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_MOVING_AVERAGES "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_HISTOGRAM "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_ANOVA_SINGLE_FACTOR "sect-analysis-statistical"
#define GNUMERIC_HELP_LINK_ANOVA_TWO_FACTOR "sect-analysis-statistical"

/* dialog-analysis-tool-chi-squared.c */
#define GNUMERIC_HELP_LINK_CHI_SQUARED "sect-analysis-statistical"

/* dialog-analysis-tool-frequency.c */
#define GNUMERIC_HELP_LINK_FREQUENCY "sect-analysis-statistical"

/* dialog-analysis-tool-kaplan-meier.c */
#define GNUMERIC_HELP_LINK_KAPLAN_MEIER "sect-analysis-statistical"

/* dialog-analysis-tool-normality.c */
#define GNUMERIC_HELP_LINK_NORMALITY "sect-analysis-statistical"

/* dialog-analysis-tool-sign-test.c */
#define GNUMERIC_HELP_LINK_SIGN_TEST "sect-analysis-statistical"

/* dialog-consolidate.c     */
#define GNUMERIC_HELP_LINK_CONSOLIDATE ""

/* dialog-fill-series.c     */
#define GNUMERIC_HELP_LINK_FILL_SERIES "sect-data-entry"

/* dialog-random-generator.c */
#define GNUMERIC_HELP_LINK_RANDOM_GENERATOR "sect-dataentryadv"

/* dialog-random-generator-cor.c */
#define GNUMERIC_HELP_LINK_RANDOM_GENERATOR_COR "sect-dataentryadv"

/* dialog-scenarios.c */
#define GNUMERIC_HELP_LINK_SCENARIOS_ADD "sect-advanced-analysis-scenarios"
#define GNUMERIC_HELP_LINK_SCENARIOS_VIEW "sect-advanced-analysis-scenarios"

/* dialog-shuffle.c   */
#define GNUMERIC_HELP_LINK_DATA_SHUFFLE "sect-data-modify"

/* dialog-simulation.c */
#define GNUMERIC_HELP_LINK_SIMULATION "sect-advanced-analysis-simulation"

/* dialog-define-table.c */
#define GNUMERIC_HELP_LINK_DEFINE_TABLE "sect-data-table"

/* dialog-doc-metadata.c */
#define GNUMERIC_HELP_LINK_METADATA ""

#endif /* GNUMERIC_HELP_H */
